<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [
  <!ENTITY nbsp '&#xA0;'>
  <!ENTITY pallino '&#x25CF;'>
  <!ENTITY freccia_a_dx '&#xFFEB;'>

  <!ENTITY colore-sfondo-tenue '#e8e8e8'>

  <!ENTITY bordo '0.2pt solid #000000'>
  <!ENTITY bordo-medio '1pt solid #000000'>
  <!ENTITY bordo-spesso '1.5pt solid #000000'>

  <!ENTITY spazio-tra-sezioni '0.5mm'>

]>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/1999/XSL/Format" xmlns:ibex="http://www.xmlpdf.com/2003/ibex/Format">
  <xsl:param name="creator"></xsl:param>
  <xsl:param name="imageFolder"></xsl:param>
  <xsl:param name="versioneTemplatePDF"></xsl:param>
  <xsl:param name="apponiTimbroDigitale"></xsl:param>
  <xsl:param name="dpiTimbroDigitale"></xsl:param>
  <xsl:param name="altezzaAreaPerTimbroDigitale"></xsl:param>
  <xsl:param name="ownerPassword"></xsl:param>

  <xsl:output method="xml" indent='yes'/>
  <xsl:strip-space elements='*'/>

  <xsl:template match="/cedolino">

    <root>
      <xsl:call-template name="definisciProprietaDocumento"/>
      <xsl:call-template name="definisciLayoutDocumento"/>
      <xsl:apply-templates select="pagina"/>
    </root>

  </xsl:template>

  <!-- TEMPLATE PRINCIPALI -->
  
  <xsl:template match="pagina">
    <page-sequence master-reference="paginaCedolino">

      <xsl:call-template name ="creaFooter"/>

      <flow flow-name="corpoPagina">
        <xsl:apply-templates select="testata"/>
        <xsl:apply-templates select="voci"/>
        <xsl:apply-templates select="piede"/>
      </flow>

    </page-sequence>
  </xsl:template>

  <xsl:template match="testata">
    <xsl:call-template name="creaLogoEDatiAnagrafici"/>
    <xsl:call-template name="creaTestata"/>
  </xsl:template>

  <xsl:template match="voci">
    <table space-before.optimum="&spazio-tra-sezioni;" space-before.minimum="0mm">
      <table-column column-width='5%' />
      <table-column column-width='30%' />
      <table-column column-width='6%' />
      <table-column column-width='13%' />
      <table-column column-width='9%' />
      <table-column column-width='11%' />
      <table-column column-width='13%' />
      <table-column column-width='13%' />
      <table-header>
        <table-row border-top='&bordo-medio;'>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>Voce</xsl:with-param>
            <xsl:with-param name="textAlign">center</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>Descrizione</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>MM/AA</xsl:with-param>
            <xsl:with-param name="textAlign">center</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>Imponibile</xsl:with-param>
            <xsl:with-param name="textAlign">center</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>Quantità</xsl:with-param>
            <xsl:with-param name="textAlign">center</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>V.&nbsp;Unitario</xsl:with-param>
            <xsl:with-param name="textAlign">center</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>Trattenute</xsl:with-param>
            <xsl:with-param name="textAlign">center</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>Competenze</xsl:with-param>
            <xsl:with-param name="textAlign">center</xsl:with-param>
          </xsl:call-template>
        </table-row>
      </table-header>
      <table-body>
        <xsl:apply-templates select="voce"/>
      </table-body>
      <table-footer>

        <xsl:choose>
          <xsl:when test='../piede/totaleTrattenute = "&nbsp;" and ../piede/totaleCompetenze = "&nbsp;"'>
            <table-row border-top='&bordo-medio;'>
              <table-cell number-columns-spanned='8' text-align='right'>
                <block>(segue...)</block>
              </table-cell>
            </table-row>
            <table-row>
              <table-cell number-columns-spanned='8'>
                <block>&nbsp;</block>
              </table-cell>
            </table-row>
          </xsl:when>
          <xsl:otherwise>
            <table-row border-top='&bordo-medio;'>
              <table-cell number-columns-spanned='5'>
                <xsl:call-template name='cella-voce-footer-vuoto'/>
                <block>
                  <xsl:value-of select='../piede/taxRegione' />
                </block>
              </table-cell>
              <table-cell text-align='right' number-rows-spanned='2'>
                <xsl:call-template name='cella-voce-footer-vuoto'/>
                <xsl:call-template name='grassetto'/>
                <block>Totale&nbsp;</block>
              </table-cell>
              <table-cell border='&bordo-medio;' number-rows-spanned='2'>
                <xsl:call-template name='cella-voce-footer-totale'/>
                <block>
                  <xsl:value-of select='../piede/totaleTrattenute' />
                </block>
              </table-cell>
              <table-cell border='&bordo-medio;' number-rows-spanned='2'>
                <xsl:call-template name='cella-voce-footer-totale'/>
                <block>
                  <xsl:value-of select='../piede/totaleCompetenze' />
                </block>
              </table-cell>
            </table-row>
            <table-row>
              <table-cell number-columns-spanned='5'>
                <block>
                  <xsl:value-of select='../piede/taxComune' />
                </block>
              </table-cell>
            </table-row>
          </xsl:otherwise>
        </xsl:choose>

      </table-footer>
    </table>
  </xsl:template>

  <xsl:template match="voce">
    <table-row>
      <xsl:if test="@numeroRiga mod 2 = 0">
        <xsl:attribute name="background-color">&colore-sfondo-tenue;</xsl:attribute>
      </xsl:if>

      <xsl:call-template name='creaCellaVoce'>
        <xsl:with-param name='valore' select='codice'/>
        <xsl:with-param name="textAlign">center</xsl:with-param>
      </xsl:call-template>
      <xsl:call-template name='creaCellaVoce'>
        <xsl:with-param name='valore' select='descrizione'/>
      </xsl:call-template>
      <xsl:call-template name='creaCellaVoce'>
        <xsl:with-param name='valore' select='mmaa'/>
        <xsl:with-param name="textAlign">center</xsl:with-param>
      </xsl:call-template>
      <xsl:call-template name='creaCellaVoce'>
        <xsl:with-param name='valore' select='imponibile'/>
        <xsl:with-param name="textAlign">right</xsl:with-param>
      </xsl:call-template>
      <xsl:call-template name='creaCellaVoce'>
        <xsl:with-param name='valore' select='quantita'/>
        <xsl:with-param name="textAlign">right</xsl:with-param>
      </xsl:call-template>
      <xsl:call-template name='creaCellaVoce'>
        <xsl:with-param name='valore' select='vUnitario'/>
        <xsl:with-param name="textAlign">right</xsl:with-param>
      </xsl:call-template>
      <xsl:call-template name='creaCellaVoce'>
        <xsl:with-param name='valore' select='trattenute'/>
        <xsl:with-param name="textAlign">right</xsl:with-param>
      </xsl:call-template>
      <xsl:call-template name='creaCellaVoce'>
        <xsl:with-param name='valore' select='competenze'/>
        <xsl:with-param name="textAlign">right</xsl:with-param>
      </xsl:call-template>

    </table-row>
  </xsl:template>

  <xsl:template match="piede">
    <xsl:call-template name="creaPiede1"/>
    <xsl:if test='not(contains("PS,AC,AE,BS,CL,CR,FD,FP,SC,SS,TI,CN,CM,CI,PI,PB,BN,TN,CS,EL,EM,EP,EB,CA,CG,VI,VR,RC,DC,G1", ../testata/tipoDipendente))'>
      <xsl:call-template name="creaMontantiAnnui1"/>
    </xsl:if>
    <xsl:call-template name="creaPiede2"/>
  </xsl:template>

  <!-- TEMPLATE SECONDARI -->

  <xsl:template name="definisciProprietaDocumento">
    
    <ibex:security deny-modify='true' owner-password='$ownerPassword'/>
    <ibex:properties>
      <xsl:attribute name='title'>Cedolino di <xsl:value-of select='pagina/testata/nominativo'/>, <xsl:value-of select='pagina/testata/meseRetribuzione'/>&nbsp;<xsl:value-of select='pagina/testata/annoRetribuzione'/></xsl:attribute>
      <xsl:attribute name='author'>Regione Emilia-Romagna</xsl:attribute>
      <xsl:attribute name='creator'><xsl:value-of select='$creator'/></xsl:attribute>
      <ibex:custom name="Mese retribuzione">
        <xsl:attribute name="value"><xsl:value-of select='pagina/testata/meseRetribuzione'/></xsl:attribute>
      </ibex:custom>
      <ibex:custom name="Anno retribuzione">
        <xsl:attribute name="value"><xsl:value-of select='pagina/testata/annoRetribuzione'/></xsl:attribute>
      </ibex:custom>
    </ibex:properties>
    
  </xsl:template>

  <xsl:template name="definisciLayoutDocumento">
    
    <layout-master-set>
      <simple-page-master master-name="paginaCedolino" page-width="210mm" page-height="297mm" margin-top="13mm" margin-bottom="13mm" margin-left="13mm" margin-right="13mm" font="8pt helvetica">
        <region-body region-name="corpoPagina" margin-top='0cm' margin-bottom="0mm" margin-left="0mm" margin-right="0mm"/>
        <region-after region-name="footer" font-size='0.8em' display-align='after'>
          <xsl:attribute name="extent"><xsl:value-of select='4 + $altezzaAreaPerTimbroDigitale'/>mm</xsl:attribute>
          <!-- il valore "4" (che nell' "extent" è sommato a $altezzaAreaPerTimbroDigitale) corrisponde all'altezza della riga di footer contenente il nome della versione e il numero della pagina (vedi 'creaFooter')-->
        </region-after>
      </simple-page-master>
    </layout-master-set>

  </xsl:template>

  <xsl:template name="creaLogoEDatiAnagrafici">

    <table widths='40%,60%' border-collapse="separate">
      <table-column column-width='40%' />
      <table-column column-width='60%' />
      <table-body>
        <table-row>
          <table-cell display-align='center'>
            <block text-align='center'>
              <xsl:choose>
                <xsl:when test='contains("CI,CM,PI,PB", tipoDipendente)'>
                  <xsl:call-template name='creaExternalGraphic'>
                    <xsl:with-param name='nomeFileImmagine'>LOG_IBC_RER_2007_RGB.jpg</xsl:with-param>
                    <xsl:with-param name='percentualeDiScala'>50%</xsl:with-param>
                  </xsl:call-template>
                </xsl:when>
                <xsl:when test='contains("CN,BN,TN,CS,CA,CG,VI,VR,RC,DC,G1", tipoDipendente)'>
                  <xsl:call-template name='creaExternalGraphic'>
                    <xsl:with-param name='nomeFileImmagine'>LOG_CONS.jpg</xsl:with-param>
                    <xsl:with-param name='percentualeDiScala'>100%</xsl:with-param>
                  </xsl:call-template>
                </xsl:when>
                <xsl:when test='contains("EC,ED,EO,EI,ER,EL,EM,EP,EB", tipoDipendente)'>
                  <xsl:call-template name='creaExternalGraphic'>
                    <xsl:with-param name='nomeFileImmagine'>LOGO_ERGO.jpg</xsl:with-param>
                    <xsl:with-param name='percentualeDiScala'>8%</xsl:with-param>
                  </xsl:call-template>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:call-template name='creaExternalGraphic'>
                    <xsl:with-param name='nomeFileImmagine'>LogoRegione.svg</xsl:with-param>
                    <xsl:with-param name='percentualeDiScala'>80%</xsl:with-param>
                  </xsl:call-template>
                </xsl:otherwise>
              </xsl:choose>
            </block>
          </table-cell>
          <table-cell>
            <xsl:call-template name='cella-arrotondata'/>
            <block >
              <block>
                <xsl:call-template name="piu-grande"/>
                <xsl:call-template name="grassetto"/>
                <xsl:value-of select='nominativo'/>
              </block>
              <xsl:choose>
                <xsl:when test='string-length(presso) &gt; 0'>
                  c/o <xsl:value-of select='presso'/>
                </xsl:when>
                <xsl:otherwise>
                  &nbsp;
                </xsl:otherwise>
              </xsl:choose>
              <block/>
              <xsl:value-of select='indirizzo'/>
              <block />
              <xsl:value-of select='cap'/>
              &nbsp;
              <xsl:value-of select='localita'/>
              &nbsp;
              <xsl:value-of select='provincia'/>
            </block>
          </table-cell>
        </table-row>
      </table-body>
    </table>

  </xsl:template>

  <xsl:template name="creaTestata">
    <table>
      <table-column column-width='13%' />
      <table-column column-width='4%' />
      <table-column column-width='3%' />
      <table-column column-width='4%' />
      <table-column column-width='9%' />
      <table-column column-width='23%' />
      <table-column column-width='8%' />
      <table-column column-width='14%' />
      <table-column column-width='11%' />
      <table-column column-width='11%' />
      <table-body>
        <table-row>
          <xsl:call-template name='creaCellaStd'>
            <xsl:with-param name='etichetta'>Matricola</xsl:with-param>
            <xsl:with-param name='valore' select='matricola' />
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd'>
            <xsl:with-param name='etichetta'>Codice&nbsp;Fiscale</xsl:with-param>
            <xsl:with-param name='valore' select='codiceFiscale' />
            <xsl:with-param name='numberColumnsSpanned'>4</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd'>
            <xsl:with-param name='etichetta'>Luogo&nbsp;Nascita</xsl:with-param>
            <xsl:with-param name='valore' select='luogoNascita' />
            <xsl:with-param name='numberColumnsSpanned'>2</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd'>
            <xsl:with-param name='etichetta'>Data&nbsp;nascita</xsl:with-param>
            <xsl:with-param name='valore' select='dataNascita' />
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd'>
            <xsl:with-param name='etichetta'>Mese&nbsp;retribuzione</xsl:with-param>
            <xsl:with-param name='valore'><xsl:value-of select='meseRetribuzione'/>&nbsp;<xsl:value-of select='annoRetribuzione'/></xsl:with-param>
            <xsl:with-param name='numberColumnsSpanned'>2</xsl:with-param>
          </xsl:call-template>
        </table-row>
        <table-row>
          <xsl:call-template name='creaCellaStd'>
            <xsl:with-param name='etichetta'>Categoria</xsl:with-param>
            <xsl:with-param name='valore' select='categoria' />
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd'>
            <xsl:with-param name='etichetta'>Centro&nbsp;Di&nbsp;Costo</xsl:with-param>
            <xsl:with-param name='valore' select='centroDiCosto' />
            <xsl:with-param name='numberColumnsSpanned'>4</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd'>
            <xsl:with-param name='etichetta'>Servizio</xsl:with-param>
            <xsl:with-param name='valore' select='servizio' />
            <xsl:with-param name='numberColumnsSpanned'>5</xsl:with-param>
          </xsl:call-template>
        </table-row>
        <table-row>
          <xsl:call-template name='creaCellaStd'>
            <xsl:with-param name='etichetta'>Inail</xsl:with-param>
            <xsl:with-param name='valore' select='inail' />
          </xsl:call-template>
          <table-cell display-align='center'>
            <xsl:call-template name='cella-bordata-centrata'/>
            <block>ANF</block>
          </table-cell>
          <xsl:call-template name='creaCellaStd'>
            <xsl:with-param name='etichetta'>Nr.</xsl:with-param>
            <xsl:with-param name='valore' select='anf_nr' />
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd'>
            <xsl:with-param name='etichetta'>Tab.</xsl:with-param>
            <xsl:with-param name='valore' select='anf_tab' />
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd'>
            <xsl:with-param name='etichetta'>%&nbsp;Occupaz.</xsl:with-param>
            <xsl:with-param name='valore' select='anf_percOccupaz' />
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd'>
            <xsl:with-param name='etichetta'>Contratto&nbsp;Di&nbsp;Lavoro</xsl:with-param>
            <xsl:with-param name='valore' select='contrattoDiLavoro' />
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd'>
            <xsl:with-param name='etichetta'>Tipo&nbsp;Rapporto</xsl:with-param>
            <xsl:with-param name='valore' select='tipoRapporto' />
            <xsl:with-param name='numberColumnsSpanned'>2</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd'>
            <xsl:with-param name='etichetta'>Assunzione</xsl:with-param>
            <xsl:with-param name='valore' select='assunzione' />
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd'>
            <xsl:with-param name='etichetta'>Cessazione</xsl:with-param>
            <xsl:with-param name='valore' select='cessazione' />
          </xsl:call-template>
        </table-row>
      </table-body>
    </table>
  </xsl:template>

  <xsl:template name="creaPiede1">

    <table space-before.optimum="&spazio-tra-sezioni;" space-before.minimum="0mm">
      <table-column column-width='11%' />
      <table-column column-width='13%' />
      <table-column column-width='11%' />
      <table-column column-width='13%' />
      <table-column column-width='3%' />
      <table-column column-width='5%' />
      <table-column column-width='4%' />
      <table-column column-width='6%' />
      <table-column column-width='6%' />
      <table-column column-width='15%' />
      <table-column column-width='13%' />
      <table-body>
        <table-row border-top='&bordo-medio;'>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>IRPEF</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>Mese&nbsp;corrente</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>Detrazioni</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>Detr.&nbsp;non&nbsp;godute</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>Tax&nbsp;Distinta</xsl:with-param>
            <xsl:with-param name='numberColumnsSpanned'>3</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>Tax&nbsp;Separata</xsl:with-param>
            <xsl:with-param name='numberColumnsSpanned'>2</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>Tot.&nbsp;Contr.&nbsp;Dip.</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>IRPEF&nbsp;Netta</xsl:with-param>
          </xsl:call-template>
        </table-row>
        <table-row>
          <xsl:call-template name='creaCellaStd2'>
            <xsl:with-param name='valoreRiga1'>Imponibile</xsl:with-param>
            <xsl:with-param name='valoreRiga2'>IRPEF&nbsp;Lorda</xsl:with-param>
            <xsl:with-param name='grassetto'>true</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd2'>
            <xsl:with-param name='valoreRiga1' select='imponibileMeseCorrente'/>
            <xsl:with-param name='valoreRiga2' select='irpefLordaMeseCorrente'/>
            <xsl:with-param name='textAlign'>right</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd2'>
            <xsl:with-param name='valoreRiga1'>&nbsp;</xsl:with-param>
            <xsl:with-param name='valoreRiga2' select='irpefLordaDetrazioni'/>
            <xsl:with-param name='textAlign'>right</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd2'>
            <xsl:with-param name='valoreRiga1'>&nbsp;</xsl:with-param>
            <xsl:with-param name='valoreRiga2' select='irpefLordaDiffDetraz'/>
            <xsl:with-param name='textAlign'>right</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd2'>
            <xsl:with-param name='valoreRiga1' select='imponibileTaxDistinta'/>
            <xsl:with-param name='valoreRiga2' select='irpefLordaTaxDistinta'/>
            <xsl:with-param name='textAlign'>right</xsl:with-param>
            <xsl:with-param name='numberColumnsSpanned'>3</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd2'>
            <xsl:with-param name='valoreRiga1' select='imponibileTaxSeparata'/>
            <xsl:with-param name='valoreRiga2' select='irpefLordaTaxSeparata'/>
            <xsl:with-param name='textAlign'>right</xsl:with-param>
            <xsl:with-param name='numberColumnsSpanned'>2</xsl:with-param>
          </xsl:call-template>
          <table-cell text-align='right' >
            <xsl:call-template name='cella-bordata'/>
            <table>
              <table-column column-width='15%' />
              <table-column column-width='85%' />
              <table-body>
                <table-row>
                  <table-cell>
                    <block>
                      TC
                    </block>
                  </table-cell>
                  <table-cell>
                    <block>
                      <xsl:value-of select='imponibileContrTaxCorr'/>
                    </block>
                  </table-cell>
                </table-row>
                <table-row>
                  <table-cell>
                    <block>
                      TS
                    </block>
                  </table-cell>
                  <table-cell>
                    <block>
                      <xsl:value-of select='imponibileContrTaxSep'/>
                    </block>
                  </table-cell>
                </table-row>
              </table-body>
            </table>
          </table-cell>
          <xsl:call-template name='creaCellaStd2'>
            <xsl:with-param name='valoreRiga1'>&nbsp;</xsl:with-param>
            <xsl:with-param name='valoreRiga2' select='irpefNetta'/>
            <xsl:with-param name='textAlign'>right</xsl:with-param>
          </xsl:call-template>

        </table-row>
        <table-row>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>Detr.&nbsp;Lav.&nbsp;Dip.</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>Coniuge</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>Figli&nbsp;&gt;&nbsp;3&nbsp;anni</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>Figli&nbsp;&lt;&nbsp;3&nbsp;anni</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>F.&nbsp;&gt;3&nbsp;anni&nbsp;inab.</xsl:with-param>
            <xsl:with-param name='numberColumnsSpanned'>3</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>F.&nbsp;&lt;3&nbsp;anni&nbsp;inab.</xsl:with-param>
            <xsl:with-param name='numberColumnsSpanned'>2</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>Altri&nbsp;familiari</xsl:with-param>
          </xsl:call-template>
          <table-cell text-align='center' border='&bordo-medio;' display-align='center'>
            <xsl:attribute name="background-color">&colore-sfondo-tenue;</xsl:attribute>            
            <xsl:call-template name='grassetto'/>
            <xsl:call-template name='piu-piccolo'/>
            <block>
              NETTO&nbsp;A&nbsp;PAGARE
            </block>
          </table-cell>
        </table-row>
        <table-row>
          <xsl:call-template name='creaCellaStd2'>
            <xsl:with-param name='valoreRiga1'>&nbsp;</xsl:with-param>
            <xsl:with-param name='valoreRiga2' select='detrazioniLavoroDipendente'/>
            <xsl:with-param name='textAlign'>right</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd2'>
            <xsl:with-param name='valoreRiga1'>&nbsp;</xsl:with-param>
            <xsl:with-param name='valoreRiga2' select='detrazioniConiuge'/>
            <xsl:with-param name='textAlign'>right</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaDetrazioniFamiliari'>
            <xsl:with-param name='numero' select='detrazioniFigliMaggiori3Anni_Nr'/>
            <xsl:with-param name='percentuale' select='detrazioniFigliMaggiori3Anni_Perc'/>
            <xsl:with-param name='detrazione' select='detrazioniMaggiori3Anni'/>
          </xsl:call-template>
          <xsl:call-template name='creaCellaDetrazioniFamiliari'>
            <xsl:with-param name='numero' select='detrazioniFigliMinori3Anni_Nr'/>
            <xsl:with-param name='percentuale' select='detrazioniFigliMinori3Anni_Perc'/>
            <xsl:with-param name='detrazione' select='detrazioniMinori3Anni'/>
          </xsl:call-template>
          <xsl:call-template name='creaCellaDetrazioniFamiliari'>
            <xsl:with-param name='numero' select='detrazioniFigliMaggiori3AnniInabili_Nr'/>
            <xsl:with-param name='percentuale' select='detrazioniFigliMaggiori3AnniInabili_Perc'/>
            <xsl:with-param name='detrazione' select='detrazioniMaggiori3AnniInabili'/>
            <xsl:with-param name='numberColumnsSpanned'>3</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaDetrazioniFamiliari'>
            <xsl:with-param name='numero' select='detrazioniFigliMinori3AnniInabili_Nr'/>
            <xsl:with-param name='percentuale' select='detrazioniFigliMinori3AnniInabili_Perc'/>
            <xsl:with-param name='detrazione' select='detrazioniMinori3AnniInabili'/>
            <xsl:with-param name='numberColumnsSpanned'>2</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaDetrazioniFamiliari'>
            <xsl:with-param name='numero' select='detrazioniAltriFamiliari_Nr'/>
            <xsl:with-param name='percentuale' select='detrazioniAltriFamiliari_Perc'/>
            <xsl:with-param name='detrazione' select='detrazioniAltriFamiliari'/>
          </xsl:call-template>
          <table-cell text-align='center' display-align='center' border='&bordo-medio;' number-rows-spanned='3' font-size='1.2em'>
            <xsl:call-template name='grassetto'/>
            <block >
              <xsl:value-of select='nettoAPagare'/>
            </block>
          </table-cell>
        </table-row>
        <table-row>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>Banca</xsl:with-param>
            <xsl:with-param name='numberColumnsSpanned'>5</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>IBAN</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>CIN</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>ABI</xsl:with-param>
            <xsl:with-param name='textAlign'>center</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>CAB</xsl:with-param>
            <xsl:with-param name='textAlign'>center</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>Conto&nbsp;Corrente</xsl:with-param>
            <xsl:with-param name='textAlign'>center</xsl:with-param>
          </xsl:call-template>
        </table-row>
        <table-row>
          <xsl:call-template name='creaCellaStd2'>
            <xsl:with-param name='valoreRiga1' select='banca1'/>
            <xsl:with-param name='valoreRiga2' select='banca2'/>
            <xsl:with-param name='numberColumnsSpanned'>5</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd2'>
            <xsl:with-param name='valoreRiga1' select='iban1'/>
            <xsl:with-param name='valoreRiga2' select='iban2'/>
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd2'>
            <xsl:with-param name='valoreRiga1' select='cin1'/>
            <xsl:with-param name='valoreRiga2' select='cin2'/>
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd2'>
            <xsl:with-param name='valoreRiga1' select='abi1'/>
            <xsl:with-param name='valoreRiga2' select='abi2'/>
            <xsl:with-param name='textAlign'>center</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd2'>
            <xsl:with-param name='valoreRiga1' select='cab1'/>
            <xsl:with-param name='valoreRiga2' select='cab2'/>
            <xsl:with-param name='textAlign'>center</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd2'>
            <xsl:with-param name='valoreRiga1' select='contoCorrente1'/>
            <xsl:with-param name='valoreRiga2' select='contoCorrente2'/>
            <xsl:with-param name='textAlign'>center</xsl:with-param>
          </xsl:call-template>
        </table-row>
      </table-body>
    </table>

  </xsl:template>

  <xsl:template name="creaMontantiAnnui1">

    <table>
      <table-column column-width='22%' />
      <table-column column-width='13%' />
      <table-column column-width='13%' />
      <table-column column-width='13%' />
      <table-column column-width='13%' />
      <table-column column-width='13%' />
      <table-column column-width='13%' />
      <table-body>
        <table-row>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>Montanti&nbsp;annui</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>Cassa&nbsp;pensione</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>INADEL</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>Fondo&nbsp;credito</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>CASAGIT</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>Previd.&nbsp;compl.</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>TFR</xsl:with-param>
          </xsl:call-template>
        </table-row>
        <table-row>
          <xsl:call-template name='creaCellaStd4'>
            <xsl:with-param name='valoreRiga1'>Imponibile&nbsp;AC</xsl:with-param>
            <xsl:with-param name='valoreRiga2'>Contributi&nbsp;AC</xsl:with-param>
            <xsl:with-param name='valoreRiga3'>Imponibile&nbsp;AP</xsl:with-param>
            <xsl:with-param name='valoreRiga4'>Contributi&nbsp;AP</xsl:with-param>
            <xsl:with-param name='grassetto'>true</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd4'>
            <xsl:with-param name='valoreRiga1' select='imponibileAC_CassaPensione'/>
            <xsl:with-param name='valoreRiga2' select='contributiAC_CassaPensione'/>
            <xsl:with-param name='valoreRiga3' select='imponibileAP_CassaPensione'/>
            <xsl:with-param name='valoreRiga4' select='contributiAP_CassaPensione'/>
            <xsl:with-param name='textAlign'>right</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd4'>
            <xsl:with-param name='valoreRiga1' select='imponibileAC_Inadel'/>
            <xsl:with-param name='valoreRiga2' select='contributiAC_Inadel'/>
            <xsl:with-param name='valoreRiga3' select='imponibileAP_Inadel'/>
            <xsl:with-param name='valoreRiga4' select='contributiAP_Inadel'/>
            <xsl:with-param name='textAlign'>right</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd4'>
            <xsl:with-param name='valoreRiga1' select='imponibileAC_FondoCredito'/>
            <xsl:with-param name='valoreRiga2' select='contributiAC_FondoCredito'/>
            <xsl:with-param name='valoreRiga3' select='imponibileAP_FondoCredito'/>
            <xsl:with-param name='valoreRiga4' select='contributiAP_FondoCredito'/>
            <xsl:with-param name='textAlign'>right</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd4'>
            <xsl:with-param name='valoreRiga1' select='imponibileAC_CasaGit'/>
            <xsl:with-param name='valoreRiga2' select='contributiAC_CasaGit'/>
            <xsl:with-param name='valoreRiga3'>&nbsp;</xsl:with-param>
            <xsl:with-param name='valoreRiga4'>&nbsp;</xsl:with-param>
            <xsl:with-param name='textAlign'>right</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd4'>
            <xsl:with-param name='valoreRiga1' select='imponibileAC_PrevidCompl'/>
            <xsl:with-param name='valoreRiga2' select='contributiAC_PrevidCompl'/>
            <xsl:with-param name='valoreRiga3'>&nbsp;</xsl:with-param>
            <xsl:with-param name='valoreRiga4'>&nbsp;</xsl:with-param>
            <xsl:with-param name='textAlign'>right</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd4'>
            <xsl:with-param name='valoreRiga1' select='imponibileAC_Tfr'/>
            <xsl:with-param name='valoreRiga2' select='contributiAC_Tfr'/>
            <xsl:with-param name='valoreRiga3' select='imponibileAP_Tfr'/>
            <xsl:with-param name='valoreRiga4' select='contributiAP_Tfr'/>
            <xsl:with-param name='textAlign'>right</xsl:with-param>
          </xsl:call-template>
        </table-row>
      </table-body>
    </table>

  </xsl:template>

  <xsl:template name='creaPiede2'>
    <table>
      <table-column column-width='35%' />
      <table-column column-width='65%' />
      <table-body>
        <table-row>
          <table-cell>
            <xsl:call-template name='creaMontantiAnnui2'/>
          </table-cell>
          <table-cell>
            <xsl:call-template name='cella-bordata'/>
            <xsl:call-template name='creaNote'/>
          </table-cell>
        </table-row>
      </table-body>
    </table>
  </xsl:template>

  <xsl:template name="creaMontantiAnnui2">

    <table width="100%">
      <table-column column-width='63%' />
      <table-column column-width='37%' />
      <table-body>
        <table-row>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>Montanti&nbsp;annui</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaHeader'>
            <xsl:with-param name='etichetta'>IRPEF</xsl:with-param>
          </xsl:call-template>
        </table-row>
        <table-row>
          <xsl:call-template name='creaCellaStd4'>
            <xsl:with-param name='valoreRiga1'>Imponibile&nbsp;Fiscale</xsl:with-param>
            <xsl:with-param name='valoreRiga2'>Imposta&nbsp;Lorda</xsl:with-param>
            <xsl:with-param name='valoreRiga3'>Detrazioni</xsl:with-param>
            <xsl:with-param name='valoreRiga4'>Imposta&nbsp;Netta</xsl:with-param>
            <xsl:with-param name='grassetto'>true</xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name='creaCellaStd4'>
            <xsl:with-param name='valoreRiga1' select='imponibileFiscale_Irpef'/>
            <xsl:with-param name='valoreRiga2' select='impostaLorda_Irpef'/>
            <xsl:with-param name='valoreRiga3' select='detrazioni_Irpef'/>
            <xsl:with-param name='valoreRiga4' select='impostaNetta_Irpef'/>
            <xsl:with-param name='textAlign'>right</xsl:with-param>
          </xsl:call-template>
        </table-row>
      </table-body>
    </table>

  </xsl:template>

  <xsl:template name="creaNote">
    <table width="100%">
      <table-column column-width='7%' />
      <table-column column-width='93%' />
      <table-body>
        <table-row>
          <table-cell>
            <xsl:call-template name='grassetto'/>
            <block>
              Note:
            </block>
          </table-cell>
          <table-cell>
            <table>
              <table-body>
                <table-row>
                  <table-cell>
                    <block>
                      <xsl:value-of select='note_riga1'/>
                    </block>
                  </table-cell>
                </table-row>
                <table-row>
                  <table-cell>
                    <block>
                      <xsl:value-of select='note_riga2'/>
                    </block>
                  </table-cell>
                </table-row>
                <table-row>
                  <table-cell>
                    <block>
                      <xsl:value-of select='note_riga3'/>
                    </block>
                  </table-cell>
                </table-row>
                <table-row>
                  <table-cell>
                    <block>
                      <xsl:value-of select='note_riga4'/>
                    </block>
                  </table-cell>
                </table-row>
                <table-row>
                  <table-cell>
                    <block>
                      <xsl:value-of select='note_riga5'/>
                    </block>
                  </table-cell>
                </table-row>
              </table-body>
            </table>
          </table-cell>
        </table-row>
      </table-body>
    </table>

  </xsl:template>

  <xsl:template name="creaFooter">

    <static-content flow-name="footer">

      <xsl:if test='$apponiTimbroDigitale'>
        <table space-before.optimum="&spazio-tra-sezioni;" space-before.minimum="0mm">
          <xsl:attribute name="block-progression-dimension"><xsl:value-of select='$altezzaAreaPerTimbroDigitale'/>mm</xsl:attribute>
          <table-body>
            <table-row>
              <table-cell display-align='after' text-align='center'>
                <block>
                  Per la decodifica del timbro seguire le istruzioni all'indirizzo <inline font-weight="bold" letter-spacing="0.1em"><basic-link external-destination='url(http://www.regione.emilia-romagna.it/TimbroDigitale/Cedolino/)'>http://www.regione.emilia-romagna.it/TimbroDigitale/Cedolino/</basic-link></inline>
                </block>
              </table-cell>
            </table-row>
            <table-row>
              <table-cell display-align='center' text-align='center'>
                <block>
                  <external-graphic ibex:anti-alias="false" content-width="100%" content-height="100%">
                    <xsl:attribute name='src'>url(data:application/ibex-image,timbroDigitale<xsl:value-of select='@numero'/>)</xsl:attribute>
                    <xsl:attribute name='dpi'><xsl:value-of select='$dpiTimbroDigitale'/></xsl:attribute>
                  </external-graphic>
                </block>
              </table-cell>
            </table-row>
          </table-body>
        </table>
      </xsl:if>
      
      <table block-progression-dimension='4mm' display-align='after'>
        <table-body>
          <!-- Se si cambia la 'height' di questa riga cambiare di conseguenza l'extent della region "footer" (nel template 'definisciLayoutDocumento') -->
          <table-row>
            <table-cell text-align='left'>
              <block >
                (Mod. <xsl:value-of select='$versioneTemplatePDF'/>)
              </block>
            </table-cell>
            <table-cell text-align='right'>
              <block >
                Pag. <xsl:value-of select='@numero'/>/<xsl:value-of select='../@numeroPagine'/>
              </block>
            </table-cell>
          </table-row>
        </table-body>
      </table>

    </static-content>

  </xsl:template>

  <!-- UTILITA' -->

  <xsl:template name="creaCellaStd">
    <xsl:param name="etichetta"/>
    <xsl:param name="valore"/>
    <xsl:param name="numberColumnsSpanned"/>
    <table-cell>
      <xsl:attribute name="number-columns-spanned"><xsl:value-of select="$numberColumnsSpanned"/></xsl:attribute>
      <xsl:call-template name='cella-bordata-centrata'/>
      <table>
        <table-body>
          <table-row>
            <table-cell>
              <block>
                <xsl:value-of select='$etichetta'/>
              </block>
            </table-cell>
          </table-row>
          <table-row>
            <table-cell>
              <xsl:call-template name='grassetto'/>
              <block>
                <xsl:value-of select='$valore'/>
              </block>
            </table-cell>
          </table-row>
        </table-body>
      </table>
    </table-cell>
  </xsl:template>

  <xsl:template name="creaCellaDetrazioniFamiliari">
    <xsl:param name="numero"/>
    <xsl:param name="percentuale"/>
    <xsl:param name="detrazione"/>
    <xsl:param name="numberColumnsSpanned"/>
    <table-cell>
      <xsl:attribute name="number-columns-spanned"><xsl:value-of select="$numberColumnsSpanned"/></xsl:attribute>
      <xsl:call-template name='cella-bordata'/>
      <table>
        <table-column column-width='32%' />
        <table-column column-width='68%' />
        <table-body>
          <table-row>
            <table-cell>
              <block>
                N.&nbsp;<xsl:value-of select='$numero'/>
              </block>
            </table-cell>
            <table-cell>
              <block>
                %&nbsp;<xsl:value-of select='$percentuale'/>
              </block>
            </table-cell>
          </table-row>
          <table-row>
            <table-cell text-align='right' number-columns-spanned='2'>
              <block>
                <xsl:value-of select='$detrazione'/>
              </block>
            </table-cell>
          </table-row>
        </table-body>
      </table>
    </table-cell>
  </xsl:template>

  <xsl:template name="creaCellaStd2">
    <xsl:param name="valoreRiga1"/>
    <xsl:param name="valoreRiga2"/>
    <xsl:param name="textAlign"/>
    <xsl:param name="numberColumnsSpanned"/>
    <xsl:param name="grassetto"/>
    <table-cell>
      <xsl:attribute name="number-columns-spanned"><xsl:value-of select="$numberColumnsSpanned"/></xsl:attribute>
      <xsl:attribute name="text-align"><xsl:value-of select="$textAlign"/></xsl:attribute>
      <xsl:call-template name='cella-bordata'/>
      <table>
        <table-body>
          <table-row>
            <table-cell>
              <xsl:if test='$grassetto'>
                <xsl:call-template name='grassetto'/>
              </xsl:if>
              <block>
                <xsl:value-of select='$valoreRiga1'/>
              </block>
            </table-cell>
          </table-row>
          <table-row>
            <table-cell>
              <xsl:if test='$grassetto'>
                <xsl:call-template name='grassetto'/>
              </xsl:if>
              <block>
                <xsl:value-of select='$valoreRiga2'/>
              </block>
            </table-cell>
          </table-row>
        </table-body>
      </table>
    </table-cell>
  </xsl:template>

  <xsl:template name="creaCellaStd4">
    <xsl:param name="valoreRiga1"/>
    <xsl:param name="valoreRiga2"/>
    <xsl:param name="valoreRiga3"/>
    <xsl:param name="valoreRiga4"/>
    <xsl:param name="textAlign"/>
    <xsl:param name="numberColumnsSpanned"/>
    <xsl:param name="grassetto"/>
    <table-cell>
      <xsl:attribute name="number-columns-spanned"><xsl:value-of select="$numberColumnsSpanned"/></xsl:attribute>
      <xsl:attribute name="text-align"><xsl:value-of select="$textAlign"/></xsl:attribute>
      <xsl:call-template name='cella-bordata'/>
      <table>
        <table-body>
          <table-row>
            <table-cell>
              <xsl:if test='$grassetto'>
                <xsl:call-template name='grassetto'/>
              </xsl:if>
              <block>
                <xsl:value-of select='$valoreRiga1'/>
              </block>
            </table-cell>
          </table-row>
          <table-row>
            <table-cell>
              <xsl:if test='$grassetto'>
                <xsl:call-template name='grassetto'/>
              </xsl:if>
              <block>
                <xsl:value-of select='$valoreRiga2'/>
              </block>
            </table-cell>
          </table-row>
          <table-row>
            <table-cell>
              <xsl:if test='$grassetto'>
                <xsl:call-template name='grassetto'/>
              </xsl:if>
              <block>
                <xsl:value-of select='$valoreRiga3'/>
              </block>
            </table-cell>
          </table-row>
          <table-row>
            <table-cell>
              <xsl:if test='$grassetto'>
                <xsl:call-template name='grassetto'/>
              </xsl:if>
              <block>
                <xsl:value-of select='$valoreRiga4'/>
              </block>
            </table-cell>
          </table-row>
        </table-body>
      </table>
    </table-cell>
  </xsl:template>

  <xsl:template name="creaCellaHeader">
    <xsl:param name="etichetta"/>
    <xsl:param name="textAlign"/>
    <xsl:param name="numberColumnsSpanned"/>
    <table-cell>
      <xsl:attribute name="number-columns-spanned"><xsl:value-of select="$numberColumnsSpanned"/></xsl:attribute>
      <xsl:call-template name='cella-etichetta'><xsl:with-param name='textAlign' select='$textAlign'/></xsl:call-template>
      <block><xsl:value-of select='$etichetta'/></block>
    </table-cell>
  </xsl:template>

  <xsl:template name="creaCellaVoce">
    <xsl:param name="valore"/>
    <xsl:param name="textAlign"/>
    <table-cell>
      <xsl:call-template name='cella-voce'><xsl:with-param name='textAlign' select='$textAlign'/></xsl:call-template>
      <block><xsl:value-of select='$valore'/></block>
    </table-cell>
  </xsl:template>

  <xsl:template name="creaExternalGraphic">
    <xsl:param name="nomeFileImmagine"/>
    <xsl:param name="percentualeDiScala"/>
    <external-graphic>
      <xsl:attribute name='src'>url(<xsl:value-of select='$imageFolder'/><xsl:value-of  select='$nomeFileImmagine'/>)</xsl:attribute>
      <xsl:attribute name='content-width'><xsl:value-of select='$percentualeDiScala'/></xsl:attribute>
      <xsl:attribute name='content-height'><xsl:value-of select='$percentualeDiScala'/></xsl:attribute>
    </external-graphic>
  </xsl:template>

  <!-- STILI -->

  <xsl:template name="piu-grande">
    <xsl:attribute name="font-size">1.1em</xsl:attribute>
  </xsl:template>

  <xsl:template name="piu-piccolo">
    <xsl:attribute name="font-size">0.8em</xsl:attribute>
  </xsl:template>


  <xsl:template name="grassetto">
    <xsl:attribute name="font-weight">bold</xsl:attribute>
  </xsl:template>
  
  <xsl:template name="cella-arrotondata">
    <xsl:attribute name="ibex:radius-top-right">3pt</xsl:attribute>
    <xsl:attribute name="ibex:radius-top-left">3pt</xsl:attribute>
    <xsl:attribute name="padding">2pt</xsl:attribute>
    <xsl:attribute name="border">&bordo;</xsl:attribute>
    <xsl:attribute name="background-color">&colore-sfondo-tenue;</xsl:attribute>
  </xsl:template>

  <xsl:template name="cella-bordata">
    <xsl:attribute name="border">&bordo;</xsl:attribute>
    <xsl:attribute name="padding-left">1pt</xsl:attribute>
    <xsl:attribute name="padding-right">1pt</xsl:attribute>
  </xsl:template>

  <xsl:template name="cella-bordata-centrata">
    <xsl:call-template name="cella-bordata"/>
    <xsl:attribute name="text-align">center</xsl:attribute>
  </xsl:template>

  <xsl:template name="cella-etichetta">
    <xsl:param name="textAlign"/>
    <xsl:attribute name="text-align"><xsl:value-of select="$textAlign"/></xsl:attribute>
    <xsl:call-template name="cella-base"/>
    <xsl:call-template name="cella-bordata"/>
    <xsl:call-template name="grassetto"/>
    <xsl:attribute name="background-color">&colore-sfondo-tenue;</xsl:attribute>
  </xsl:template>

  <xsl:template name="cella-base">
    <xsl:attribute name="padding-left">1pt</xsl:attribute>
    <xsl:attribute name="padding-right">1pt</xsl:attribute>
    <xsl:attribute name="display-align">center</xsl:attribute>
  </xsl:template>

  <xsl:template name="cella-voce">
    <xsl:param name="textAlign"/>
    <xsl:call-template name="cella-base"/>
    <xsl:attribute name="text-align"><xsl:value-of select="$textAlign"/></xsl:attribute>
    <xsl:attribute name="border-left">&bordo;</xsl:attribute>
    <xsl:attribute name="border-right">&bordo;</xsl:attribute>
  </xsl:template>

  <xsl:template name="cella-voce-footer-vuoto">
    <xsl:call-template name="cella-base"/>
    <xsl:attribute name="border-top">&bordo;</xsl:attribute>
  </xsl:template>

  <xsl:template name="cella-voce-footer-totale">
    <xsl:call-template name="cella-voce"><xsl:with-param name="textAlign">right</xsl:with-param></xsl:call-template>
    <xsl:attribute name="border-top">&bordo;</xsl:attribute>
    <xsl:attribute name="border-bottom">&bordo;</xsl:attribute>
  </xsl:template>

</xsl:stylesheet>

